measuretools.multiply_contents_of_measures_in_expr_and_scale_meter_denominators
===============================================================================

.. autofunction:: abjad.tools.measuretools.multiply_contents_of_measures_in_expr_and_scale_meter_denominators.multiply_contents_of_measures_in_expr_and_scale_meter_denominators
